;Same as tutorial 04, but using the PureZIP_W library to compress the pdf file

#ZLIB_VERSION       = "1.2.1"
#Z_OK               = 0
#Z_NULL             = 0 
#Z_BEST_SPEED       = 1
#Z_BEST_COMPRESSION = 9

Structure strData
  pData.l       ; Pointer to memory
  lMaxSize.l    ; Max. reserved memory in bytes
  lCurSize.l    ; Current last possition of data in bytes
EndStructure

Structure z_stream
  next_in.l   
  avail_in.l  
  total_in.l  
  next_out.l  
  avail_out.l 
  total_out.l 
  msg.s       
  zalloc.l    
  zfree.l     
  opaque.l    
  data_type.l
  adler.l
  reserved.l
EndStructure

Global stream.z_stream
Global title.s
Global col.f
Global y0.f
title="20000 Leagues Under the Seas"

Procedure.b Compress(*aData.strData)
  Protected zerr.b
  Protected CompMem.l
  Protected SourceLen.l
  Protected SourceMem.l
  Protected CompLen.l
  Protected lbError.b
  
  lbError = #False
  SourceLen = *aData\lCurSize
  SourceMem = *aData\pData 
  CompLen.l = (Int(SourceLen/8000)+1)*8000 + 16 
  CompMem=AllocateMemory(CompLen)
  If CompMem
    zerr=ZLIBCompress(CompMem, @CompLen, SourceMem, SourceLen)
    If zerr = #Z_OK
      *aData\pData = CompMem
      *aData\lMaxSize = CompLen
      *aData\lCurSize = CompLen
      FreeMemory(Sourcemem)
      lbError = #True 
    EndIf
  EndIf
  ProcedureReturn lbError  
EndProcedure

Procedure Header()
  pdf_SetFont("Arial","B",15)
  w = pdf_GetStringWidth(title)+6
  pdf_SetX((210 - w)/2)
  pdf_SetDrawColor(0,80,180)
  pdf_SetFillColor(230,230,0)
  pdf_SetTextColor(220,50,50)
  pdf_SetLineWidth(1)
  pdf_Cell(w,9,title,1,1,#PDF_ALIGN_CENTER,1)
  pdf_Ln(10)
  y0 = pdf_GetY()
EndProcedure

Procedure footer()
  pdf_SetY(-15)
  pdf_SetFont("Arial","I",8)
  pdf_SetTextColor(128)
  txt.s = "Page " + Str(pdf_GetPageNo())
  pdf_Cell(0,10,txt,0,0,#PDF_ALIGN_CENTER)
EndProcedure

Procedure SetCol(cl.f)
  ;Set position at a given column
  col = cl;
  x=10+cl*65;
  pdf_SetLeftMargin(x);
  pdf_SetX(x);
EndProcedure

Procedure AcceptPageBreak()
  ;Method accepting Or not automatic page Break
  If(col<2)
    ;Go To Next column
    SetCol( col+1)
    ;Set ordinate To top
    
    pdf_SetY(y0)
    ;Keep on page
    ProcedureReturn #False
 Else
  ;Go back To first column
  SetCol(0)
  ;Page Break
  ProcedureReturn #True;
  EndIf
EndProcedure



Procedure ChapterTitle(num, label.s)
  pdf_SetFont("Arial", "",12)
  pdf_SetFillColor(200,220,255)
  pdf_Cell(0,6,"Chapter " + Str(num) + " : " + label,0,1,#PDF_ALIGN_LEFT,1)
  pdf_Ln(4)
  y0=pdf_GetY()
EndProcedure

Procedure ChapterBody(file.s)
  txt.s = ""
  OpenFile(0,file)
  l = FileSize(file)
  *MemoryBuffer = AllocateMemory(l) 

  l = ReadData(0,*MemoryBuffer, l)
  CloseFile(0)
  txt = PeekS(*MemoryBuffer ,l) 
  pdf_SetFont("Times","",12)
  pdf_MultiCell(60,5,txt)
  pdf_Ln()
  pdf_SetFont("","I")
  pdf_Cell(0,5,"(end of excerpt)")
  setcol(0)
  
EndProcedure

Procedure PrintChapter(num,atitle.s,file.s)
  pdf_AddPage()
  ChapterTitle(num,atitle)
  ChapterBody(file)
EndProcedure

pdf_Create()
pdf_SetProcFooter(@Footer())
pdf_SetProcHeader(@Header())
pdf_SetProcCompression(@Compress())
pdf_SetProcAcceptPageBreak(@AcceptPageBreak())
pdf_SetTitle(title)
pdf_SetAuthor("Jules Verne")

PrintChapter(1,"A RUNAWAY REEF","20k_c1.txt");
PrintChapter(2,"THE PROS And CONS","20k_c2.txt");
pdf_Save("Tutorial05.pdf")

; IDE Options = PureBasic v4.00 (Windows - x86)
; CursorPosition = 125
; FirstLine = 119
; Folding = --